# RevRecTrigger

Specifies the revenue recognition trigger condition.

## Enum

* `CONTRACTEFFECTIVEDATE` (value: `'ContractEffectiveDate'`)

* `SERVICEACTIVATIONDATE` (value: `'ServiceActivationDate'`)

* `CUSTOMERACCEPTANCEDATE` (value: `'CustomerAcceptanceDate'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


